{% load i18n admin_urls %} {% block object-tools-items %} {% if has_add_permission %}
<li>
    <a href="{% url 'linear:import_issues' %}" class="addlink">
        {% blocktranslate %}Import issues{% endblocktranslate %}
    </a>
</li>
{% endif %} {% endblock %}
